@@ -1,4 +1,4 @@
-/* $XdotOrg: xc/programs/xdm/dm.h,v 1.3 2004/12/15 20:49:08 herrb Exp $ */
+/* $XdotOrg: app/xdm/dm.h,v 1.5 2005/11/08 06:33:31 jkj Exp $ */
 /* $Xorg: dm.h,v 1.4 2001/02/09 02:05:40 xorgcvs Exp $ */
 /*
 
@@ -175,8 +175,8 @@ struct display {
 
 	/* display state */
 	DisplayStatus	status;		/* current status */
-	int		pid;		/* process id of child */
-	int		serverPid;	/* process id of server (-1 if none) */
+	pid_t		pid;		/* process id of child */
+	pid_t		serverPid;	/* process id of server (-1 if none) */
 	FileState	state;		/* state during HUP processing */
 	int		startTries;	/* current start try */
         Time_t          lastCrash;      /* time of last crash */
@@ -331,8 +331,8 @@ extern int	choiceTimeout;	/* chooser choice timeout */
 extern struct display	*FindDisplayByName (char *name),
 			*FindDisplayBySessionID (CARD32 sessionID),
 			*FindDisplayByAddress (XdmcpNetaddr addr, int addrlen, CARD16 displayNumber),
-			*FindDisplayByPid (int pid),
-			*FindDisplayByServerPid (int serverPid),
+			*FindDisplayByPid (pid_t pid),
+			*FindDisplayByServerPid (pid_t serverPid),
 			*NewDisplay (char *name, char *class);
 
 extern struct protoDisplay	*FindProtoDisplay (
@@ -488,11 +488,7 @@ extern void ProcessRequestSocket(int fd);
 
 #include <stdlib.h>
 
-#if defined(X_NOT_POSIX) && defined(SIGNALRETURNSINT)
-#define SIGVAL int
-#else
-#define SIGVAL void
-#endif
+#define SIGVAL RETSIGTYPE
 
 #if defined(X_NOT_POSIX) || defined(__UNIXOS2__) || defined(__NetBSD__) && defined(__sparc__)
 #if defined(SYSV) || defined(__UNIXOS2__)
